@@ -1,6 +1,6 @@
 # Copyright (C) 2008-2009 - INRIA - Michael Baudin
 # Copyright (C) 2009-2010 - DIGITEO - Michael Baudin
-# Copyright (C) 2010-2011 - Sebastien Bihorel
+# Copyright (C) 2010-2014 - Sebastien Bihorel
 #
 # This file must be used under the terms of the CeCILL.
 # This source file is licensed as described in the file COPYING, which
@@ -13,7 +13,7 @@
 
 optimbase.log <- function(this=NULL,msg=NULL){
 
-  if (this$verbose){
+  if (this$verbose==TRUE){
     if (this$logfile!=''){
       write(sprintf('%s\n',msg),file=this$logfile,append=TRUE)
     } else {
